@@ -191,6 +191,10 @@ class YUM(Bcfg2.Client.Tools.PkgTool):
         self.logger.debug("Yum: Reinstall on verify fail: %s" % self.do_reinst)
         self.logger.debug("Yum: installonlypkgs: %s" % self.installonlypkgs)
         self.logger.debug("Yum: verify_flags: %s" % self.verify_flags)
+        self.logger.debug("Yum: disabled_plugins: %s" % 
+                          self.setup["yum_disabled_plugins"])
+        self.logger.debug("Yum: enabled_plugins: %s" % 
+                          self.setup["yum_enabled_plugins"])
 
     def _loadYumBase(self, setup=None, logger=None):
         ''' this may be called before PkgTool.__init__() is called on
@@ -216,6 +220,12 @@ class YUM(Bcfg2.Client.Tools.PkgTool):
         else:
             debuglevel = 0
 
+        if setup['yum_disabled_plugins']:
+            rv.preconf.disabled_plugins = setup['yum_disabled_plugins']
+
+        if setup['yum_enabled_plugins']:
+            rv.preconf.enabled_plugins = setup['yum_enabled_plugins']
+
         # pylint: disable=E1121,W0212
         try:
             rv.preconf.debuglevel = debuglevel
@@ -580,8 +590,8 @@ class YUM(Bcfg2.Client.Tools.PkgTool):
                                         "an RPM release")
                     continue
                 pkg_objs = [p for p in all_pkg_objs
-                            if (p.version == nevra['version']
-                                and p.release == nevra['release'])]
+                            if (p.version == nevra['version'] and
+                                p.release == nevra['release'])]
             else:
                 pkg_objs = self.yumbase.rpmdb.searchNevra(**short_yname(nevra))
             if len(pkg_objs) == 0:
