@@ -234,6 +234,8 @@ class FileMonitor(Debuggable):
                         self.handles[event.requestID]))
         try:
             self.handles[event.requestID].HandleEvent(event)
+        except KeyboardInterrupt:
+            raise
         except:  # pylint: disable=W0702
             err = sys.exc_info()[1]
             LOGGER.error("Error in handling of event %s for %s: %s" %
@@ -334,8 +336,11 @@ class FileMonitor(Debuggable):
 available = dict()  # pylint: disable=C0103
 
 # TODO: loading the monitor drivers should be automatic
-from Bcfg2.Server.FileMonitor.Pseudo import Pseudo
-available['pseudo'] = Pseudo
+try:
+    from Bcfg2.Server.FileMonitor.Pseudo import Pseudo
+    available['pseudo'] = Pseudo
+except ImportError:
+    pass
 
 try:
     from Bcfg2.Server.FileMonitor.Fam import Fam
