@@ -1029,8 +1029,20 @@ class YumSource(Source):
     ptype = 'yum'
 
     def __init__(self, basepath, xsource, setup):
-        Source.__init__(self, basepath, xsource, setup)
+        self.filemap = dict()
+        self.file_to_arch = dict()
+        self.needed_paths = set()
+        self.packages = dict()
+        self.yumgroups = dict()
         self.pulp_id = None
+        self.repo = None
+
+        Source.__init__(self, basepath, xsource, setup)
+    __init__.__doc__ = Source.__init__.__doc__
+
+    def _init_attributes(self, xsource):
+        Source._init_attributes(self, xsource)
+
         if HAS_PULP and xsource.get("pulp_id"):
             self.pulp_id = xsource.get("pulp_id")
 
@@ -1063,15 +1075,11 @@ class YumSource(Source):
                                      self.repo['relative_path'])
             self.arches = [self.repo['arch']]
 
-        self.packages = dict()
         self.deps = dict([('global', dict())])
         self.provides = dict([('global', dict())])
         self.filemap = dict([(x, dict())
                              for x in ['global'] + self.arches])
-        self.needed_paths = set()
-        self.file_to_arch = dict()
-        self.yumgroups = dict()
-    __init__.__doc__ = Source.__init__.__doc__
+    _init_attributes.__doc__ = Source._init_attributes.__doc__
 
     @property
     def use_yum(self):
@@ -1161,6 +1169,94 @@ class YumSource(Source):
                 self.file_to_arch[self.escape_url(fullurl)] = arch
         return urls
 
+    # pylint: disable=R0911,R0912
+    # disabling the pylint errors above because we are interesting in
+    # replicating the flow of the RPM code.
+    def _compare_rpm_versions(self, str1, str2):
+        """ Compare RPM versions.
+
+        This is an attempt to reimplement RPM's rpmvercmp method in python.
+
+        :param str1: package 1 version string
+        :param str2: package 2 version string
+        :return: 1 - str1 is newer than str2
+                 0 - str1 and str2 are the same version
+                -1 - str2 is newer than str1"""
+        if str1 == str2:
+            return 0
+
+        front_strip_re = re.compile('^[^A-Za-z0-9~]+')
+        risdigit = re.compile('(^[0-9]+)')
+        risalpha = re.compile('(^[A-Za-z])')
+        lzeroes = re.compile('^0+')
+
+        while len(str1) > 0 or len(str2) > 0:
+            str1 = front_strip_re.sub('', str1)
+            str2 = front_strip_re.sub('', str2)
+
+            if len(str1) == 0 or len(str2) == 0:
+                break
+
+            # handle the tilde separator
+            if str1[0] == '~' and str2[0] == '~':
+                str1 = str1[1:]
+                str2 = str2[1:]
+            elif str1[0] == '~':
+                return -1
+            elif str2[0] == '~':
+                return 1
+
+            # grab continuous segments from each string
+            isnum = False
+            if risdigit.match(str1):
+                segment1 = risdigit.split(str1)[1]
+                str1 = risdigit.split(str1)[2]
+                if risdigit.match(str2):
+                    segment2 = risdigit.split(str2)[1]
+                    str2 = risdigit.split(str2)[2]
+                else:
+                    segment2 = ''
+                isnum = True
+            else:
+                segment1 = risalpha.split(str1)[1]
+                str1 = risalpha.split(str1)[2]
+                if risalpha.match(str2):
+                    segment2 = risalpha.split(str2)[1]
+                    str2 = risalpha.split(str2)[2]
+                else:
+                    segment2 = ''
+
+            # numeric segments are always newer than alpha segments
+            if len(segment2) == 0:
+                if isnum:
+                    return 1
+                return -1
+
+            if isnum:
+                # discard leading zeroes
+                segment1 = lzeroes.sub('', segment1)
+                segment2 = lzeroes.sub('', segment2)
+                # higher number has more digits
+                if len(segment1) > len(segment2):
+                    return 1
+                elif len(segment2) > len(segment1):
+                    return -1
+            # do a simple string comparison
+            if segment1 > segment2:
+                return 1
+            elif segment2 > segment1:
+                return -1
+
+        # if one of the strings is empty, the version of the longer
+        # string is higher
+        if len(str1) > len(str2):
+            return 1
+        elif len(str2) > len(str1):
+            return -1
+        else:
+            return 0
+    # pylint: enable=R0911,R0912
+
     @Bcfg2.Server.Plugin.track_statistics()
     def read_files(self):
         """ When using the builtin yum parser, read and parse locally
@@ -1229,13 +1325,33 @@ class YumSource(Source):
         if arch not in self.packages:
             self.packages[arch] = set()
         if arch not in self.deps:
-            self.deps[arch] = dict()
+            self.deps[arch] = {}
         if arch not in self.provides:
-            self.provides[arch] = dict()
+            self.provides[arch] = {}
+        versionmap = {}
         for pkg in data.getchildren():
             if not pkg.tag.endswith('package'):
                 continue
             pkgname = pkg.find(XP + 'name').text
+            vtag = pkg.find(XP + 'version')
+            epoch = vtag.get('epoch')
+            version = vtag.get('ver')
+            release = vtag.get('rel')
+            if pkgname in self.packages[arch]:
+                # skip if version older than a previous version
+                if (self._compare_rpm_versions(
+                        epoch, versionmap[pkgname]['epoch']) < 0):
+                    continue
+                elif (self._compare_rpm_versions(
+                        version, versionmap[pkgname]['version']) < 0):
+                    continue
+                elif (self._compare_rpm_versions(
+                        release, versionmap[pkgname]['release']) < 0):
+                    continue
+            versionmap[pkgname] = {}
+            versionmap[pkgname]['epoch'] = epoch
+            versionmap[pkgname]['version'] = version
+            versionmap[pkgname]['release'] = release
             self.packages[arch].add(pkgname)
 
             pdata = pkg.find(XP + 'format')
@@ -1287,10 +1403,15 @@ class YumSource(Source):
         arch = [a for a in self.arches if a in metadata.groups]
         if not arch:
             return False
-        return ((package in self.packages['global'] or
-                 package in self.packages[arch[0]]) and
-                package not in self.blacklist and
-                (len(self.whitelist) == 0 or package in self.whitelist))
+        try:
+            return ((package in self.packages['global'] or
+                     package in self.packages[arch[0]]) and
+                    package not in self.blacklist and
+                    (len(self.whitelist) == 0 or package in self.whitelist))
+        except KeyError:
+            self.logger.debug("Packages: Unable to find %s for arch %s" %
+                              (package, arch[0]))
+            return False
     is_package.__doc__ = Source.is_package.__doc__
 
     def get_vpkgs(self, metadata):
